package MT::Plugin::TemporaryFileCleaner;
use strict;
use MT;
use MT::Plugin;

our $VERSION = 0.1;

use base qw( MT::Plugin );

###################################### Init Plugin #####################################

@MT::Plugin::TemporaryFileCleaner::ISA = qw(MT::Plugin);

my $plugin = new MT::Plugin::TemporaryFileCleaner({
    id => 'TemporaryFileCleaner',
    key => 'temporaryfilecleaner',
    name => 'TemporaryFileCleaner',
	description => 'Clear any preview file that may exist.',
    author_name => 'Junnama Noda',
    author_link => 'http://junnama.alfasado.net/online/',
    'version' => $VERSION,
});

MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'MT::App::CMS::template_output.preview_strip'
                => {
                    handler => \&_TemporaryFileCleaner,
                    priority => 9,
                }
        },
   });
}

sub _TemporaryFileCleaner {
    my ($eh, $app, $tmpl, $param) = @_;
    my $blog = $app->blog;
    my $file = $param->{'preview_url'};
    my $site_url = $blog->site_url;
    my $site_path = $blog->site_path;
    if ($site_url =~ /(.*)\/$/) {
        $site_url = $1;
    }
    if ($site_path =~ /(.*)\/$/) {
        $site_path = $1;
    }
    $file =~ s/$site_url/$site_path/;
    if ($app->config->LaunchBackgroundTasks) {
    	MT::Util::start_background_task(sub { _cleanup($file) });
    }
}

sub _cleanup {
    my $file = shift;
    if (-f $file) {
        sleep 3;
        unlink $file;
    }
}

1;